==> aiofreepybox-0.0.6.tar.gz: aiofreepybox-0.0.6/setup.py <==
# -*- coding: utf-8 -*-

import codecs
import os
import re
from setuptools import setup, find_packages


# Method for retrieving the version is taken from the setup.py of pip itself:
# https://github.com/pypa/pip/blob/master/setup.py
here = os.path.abspath(os.path.dirname(__file__))


def read(*parts):
    with codecs.open(os.path.join(here, *parts), 'r') as fp:
        return fp.read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


# Get the long description from the README file
with open(os.path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()


setup(
    name='aiofreepybox',
    version=find_version("aiofreepybox", "__init__.py"),
    packages=find_packages(),
    author='stilllman',
    author_email='luc_touraille@yahoo.fr',
    description='Provides asynchronous authentication and access to Freebox servers',
    long_description=long_description,
    long_description_content_type='text/markdown',
    install_requires=['aiohttp>=3,<4'],
    include_package_data=True,
    url='https://github.com/stilllman/freepybox/tree/aiofreepybox',
    keywords='freebox async',
    classifiers=[
        'Programming Language :: Python',
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Framework :: AsyncIO',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'Topic :: Home Automation',
    ],
)

==> aiofreepybox-0.0.8.tar.gz: aiofreepybox-0.0.8/setup.py <==
# -*- coding: utf-8 -*-

import codecs
import os
import re
from setuptools import setup, find_packages


# Method for retrieving the version is taken from the setup.py of pip itself:
# https://github.com/pypa/pip/blob/master/setup.py
here = os.path.abspath(os.path.dirname(__file__))


def read(*parts):
    with codecs.open(os.path.join(here, *parts), 'r') as fp:
        return fp.read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


# Get the long description from the README file
with open(os.path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()


setup(
    name='aiofreepybox',
    version=find_version("aiofreepybox", "__init__.py"),
    packages=find_packages(),
    author='stilllman',
    author_email='luc_touraille@yahoo.fr',
    description='Provides asynchronous authentication and access to Freebox servers',
    long_description=long_description,
    long_description_content_type='text/markdown',
    install_requires=['aiohttp>=3,<4'],
    include_package_data=True,
    url='https://github.com/stilllman/aiofreepybox/tree/aiofreepybox',
    keywords='freebox async',
    classifiers=[
        'Programming Language :: Python',
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Framework :: AsyncIO',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'Topic :: Home Automation',
    ],
)
